==> kubernetes-model-1.0.21-sources.jar: io/fabric8/openshift/api/model/BuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class BuildStrategyBuilder extends BuildStrategyFluent<BuildStrategyBuilder> implements VisitableBuilder<BuildStrategy,BuildStrategyBuilder>{

     BuildStrategyFluent<?> fluent;
public BuildStrategyBuilder(){
    this(new BuildStrategy());
}
public BuildStrategyBuilder( BuildStrategyFluent<?> fluent ){
    this(fluent, new BuildStrategy());
}
public BuildStrategyBuilder( BuildStrategyFluent<?> fluent , BuildStrategy instance ){
    this.fluent = fluent; fluent.withCustomStrategy(instance.getCustomStrategy()); fluent.withDockerStrategy(instance.getDockerStrategy()); fluent.withSourceStrategy(instance.getSourceStrategy()); fluent.withType(instance.getType()); 
}
public BuildStrategyBuilder( BuildStrategy instance ){
    this.fluent = this; this.withCustomStrategy(instance.getCustomStrategy()); this.withDockerStrategy(instance.getDockerStrategy()); this.withSourceStrategy(instance.getSourceStrategy()); this.withType(instance.getType()); 
}

public EditableBuildStrategy build(){
    EditableBuildStrategy buildable = new EditableBuildStrategy(fluent.getCustomStrategy(),fluent.getDockerStrategy(),fluent.getSourceStrategy(),fluent.getType());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
BuildStrategyBuilder that = (BuildStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.35-sources.jar: io/fabric8/openshift/api/model/BuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class BuildStrategyBuilder extends BuildStrategyFluentImpl<BuildStrategyBuilder> implements VisitableBuilder<BuildStrategy,BuildStrategyBuilder>{

     BuildStrategyFluent<?> fluent;
public BuildStrategyBuilder(){
    this(new BuildStrategy());
}
public BuildStrategyBuilder( BuildStrategyFluent<?> fluent ){
    this(fluent, new BuildStrategy());
}
public BuildStrategyBuilder( BuildStrategyFluent<?> fluent , BuildStrategy instance ){
    this.fluent = fluent; fluent.withCustomStrategy(instance.getCustomStrategy()); fluent.withDockerStrategy(instance.getDockerStrategy()); fluent.withSourceStrategy(instance.getSourceStrategy()); fluent.withType(instance.getType()); 
}
public BuildStrategyBuilder( BuildStrategy instance ){
    this.fluent = this; this.withCustomStrategy(instance.getCustomStrategy()); this.withDockerStrategy(instance.getDockerStrategy()); this.withSourceStrategy(instance.getSourceStrategy()); this.withType(instance.getType()); 
}

public EditableBuildStrategy build(){
    EditableBuildStrategy buildable = new EditableBuildStrategy(fluent.getCustomStrategy(),fluent.getDockerStrategy(),fluent.getSourceStrategy(),fluent.getType());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
BuildStrategyBuilder that = (BuildStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
